ncscli is the command-line and python interface for Neocortix Cloud Services.

For an introduction, see [Neocortix Cloud Services](https://www.neocortix.com/cloud).

For Tutorials, examples and notes see [Neocortix Turorials](https://neocortix.com/tutorials)